[tor-commits] [tor/master] prop224: Don't move intro points but rather descriptors

nickm at torproject.org nickm at torproject.org
Mon Sep 4 16:10:48 UTC 2017


commit a9fb97e91aa6232619d9e0b81c47e4eb3037d0f7
Author: David Goulet <dgoulet at torproject.org>
Date:   Fri Jul 28 11:47:32 2017 -0400

    prop224: Don't move intro points but rather descriptors
    
    Apart from the fact that a newly allocated service doesn't have descriptors
    thus the move condition can never be true, the service needs the descriptor
    signing key to cross-certify the authentication key of each intro point so we
    need to move the descriptors between services and not only the intro points.
    
    Fixes #23056
    
    Signed-off-by: David Goulet <dgoulet at torproject.org>
---
 src/or/hs_service.c | 37 ++++++++++++-------------------------
 1 file changed, 12 insertions(+), 25 deletions(-)

diff --git a/src/or/hs_service.c b/src/or/hs_service.c
index 0d0db1cd6..f2e07e78c 100644
--- a/src/or/hs_service.c
+++ b/src/or/hs_service.c
@@ -709,34 +709,20 @@ close_service_circuits(hs_service_t *service)
   close_service_rp_circuits(service);
 }
 
-/* Move introduction points from the src descriptor to the dst descriptor. The
- * destination service intropoints are wiped out if any before moving. */
+/* Move descriptor(s) from the src service to the dst service. */
 static void
-move_descriptor_intro_points(hs_service_descriptor_t *src,
-                             hs_service_descriptor_t *dst)
+move_descriptors(hs_service_t *src, hs_service_t *dst)
 {
   tor_assert(src);
   tor_assert(dst);
 
-  digest256map_free(dst->intro_points.map, service_intro_point_free_);
-  dst->intro_points.map = src->intro_points.map;
-  /* Nullify the source. */
-  src->intro_points.map = NULL;
-}
-
-/* Move introduction points from the src service to the dst service. The
- * destination service intropoints are wiped out if any before moving. */
-static void
-move_intro_points(hs_service_t *src, hs_service_t *dst)
-{
-  tor_assert(src);
-  tor_assert(dst);
-
-  if (src->desc_current && dst->desc_current) {
-    move_descriptor_intro_points(src->desc_current, dst->desc_current);
+  if (src->desc_current) {
+    dst->desc_current = src->desc_current;
+    src->desc_current = NULL;
   }
-  if (src->desc_next && dst->desc_next) {
-    move_descriptor_intro_points(src->desc_next, dst->desc_next);
+  if (src->desc_next) {
+    dst->desc_next = src->desc_next;
+    src->desc_next = NULL;
   }
 }
 
@@ -812,13 +798,14 @@ register_all_services(void)
      * transfer the intro points to it. */
     s = find_service(hs_service_map, &snew->keys.identity_pk);
     if (s) {
-      /* Pass ownership of intro points from s (the current service) to snew
-       * (the newly configured one). */
-      move_intro_points(s, snew);
+      /* Pass ownership of the descriptors from s (the current service) to
+       * snew (the newly configured one). */
+      move_descriptors(s, snew);
       /* Remove the service from the global map because after this, we need to
        * go over the remaining service in that map that aren't surviving the
        * reload to close their circuits. */
       remove_service(hs_service_map, s);
+      hs_service_free(s);
     }
     /* Great, this service is now ready to be added to our new map. */
     if (BUG(register_service(new_service_map, snew) < 0)) {





More information about the tor-commits mailing list